# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xurpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xurpc.proto',
  package='xudrpc',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0bxurpc.proto\x12\x06xudrpc\x1a\x1cgoogle/api/annotations.proto\"\xea\x01\n\x12\x41\x64\x64\x43urrencyRequest\x12\x1a\n\x08\x63urrency\x18\x01 \x01(\tR\x08\x63urrency\x12G\n\x0bswap_client\x18\x02 \x01(\x0e\x32%.xudrpc.AddCurrencyRequest.SwapClientR\x0bswap_client\x12$\n\rtoken_address\x18\x03 \x01(\tR\rtoken_address\x12&\n\x0e\x64\x65\x63imal_places\x18\x04 \x01(\rR\x0e\x64\x65\x63imal_places\"!\n\nSwapClient\x12\x07\n\x03LND\x10\x00\x12\n\n\x06RAIDEN\x10\x01\"\x15\n\x13\x41\x64\x64\x43urrencyResponse\"^\n\x0e\x41\x64\x64PairRequest\x12$\n\rbase_currency\x18\x01 \x01(\tR\rbase_currency\x12&\n\x0equote_currency\x18\x02 \x01(\tR\x0equote_currency\"\x11\n\x0f\x41\x64\x64PairResponse\"0\n\nBanRequest\x12\"\n\x0cnode_pub_key\x18\x01 \x01(\tR\x0cnode_pub_key\"\r\n\x0b\x42\x61nResponse\"^\n\x0e\x43hannelBalance\x12\x18\n\x07\x62\x61lance\x18\x01 \x01(\x03R\x07\x62\x61lance\x12\x32\n\x14pending_open_balance\x18\x02 \x01(\x03R\x14pending_open_balance\"3\n\x15\x43hannelBalanceRequest\x12\x1a\n\x08\x63urrency\x18\x01 \x01(\tR\x08\x63urrency\"\xa9\x01\n\x16\x43hannelBalanceResponse\x12\x46\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32,.xudrpc.ChannelBalanceResponse.BalancesEntryR\x06orders\x1aG\n\rBalancesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.xudrpc.ChannelBalance:\x02\x38\x01\",\n\x0e\x43onnectRequest\x12\x1a\n\x08node_uri\x18\x01 \x01(\tR\x08node_uri\"\x11\n\x0f\x43onnectResponse\"\x8a\x01\n\x12\x45xecuteSwapRequest\x12\x1a\n\x08order_id\x18\x01 \x01(\tR\x08order_id\x12\x18\n\x07pair_id\x18\x02 \x01(\tR\x07pair_id\x12\"\n\x0cpeer_pub_key\x18\x03 \x01(\tR\x0cpeer_pub_key\x12\x1a\n\x08quantity\x18\x04 \x01(\x04R\x08quantity\"\xab\x01\n\x0bSwapFailure\x12\x1a\n\x08order_id\x18\x01 \x01(\tR\x08order_id\x12\x18\n\x07pair_id\x18\x02 \x01(\tR\x07pair_id\x12\x1a\n\x08quantity\x18\x03 \x01(\x04R\x08quantity\x12\"\n\x0cpeer_pub_key\x18\x04 \x01(\tR\x0cpeer_pub_key\x12&\n\x0e\x66\x61ilure_reason\x18\x05 \x01(\tR\x0e\x66\x61ilure_reason\"\x10\n\x0eGetInfoRequest\"\xe9\x02\n\x0fGetInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\"\n\x0cnode_pub_key\x18\x02 \x01(\tR\x0cnode_pub_key\x12\x12\n\x04uris\x18\x03 \x03(\tR\x04uris\x12\x1c\n\tnum_peers\x18\x04 \x01(\x05R\tnum_peers\x12\x1c\n\tnum_pairs\x18\x05 \x01(\x05R\tnum_pairs\x12+\n\x06orders\x18\x06 \x01(\x0b\x32\x13.xudrpc.OrdersCountR\x06orders\x12\x32\n\x03lnd\x18\x07 \x03(\x0b\x32 .xudrpc.GetInfoResponse.LndEntryR\x03lnd\x12*\n\x06raiden\x18\x08 \x01(\x0b\x32\x12.xudrpc.RaidenInfoR\x06raiden\x1a;\n\x08LndEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.xudrpc.LndInfo:\x02\x38\x01\"8\n\x12GetNodeInfoRequest\x12\"\n\x0cnode_pub_key\x18\x01 \x01(\tR\x0cnode_pub_key\"R\n\x13GetNodeInfoResponse\x12#\n\x0freputationScore\x18\x01 \x01(\x05R\nreputation\x12\x16\n\x06\x62\x61nned\x18\x02 \x01(\x08R\x06\x62\x61nned\"]\n\x11ListOrdersRequest\x12\x18\n\x07pair_id\x18\x01 \x01(\tR\x07pair_id\x12.\n\x12include_own_orders\x18\x02 \x01(\x08R\x12include_own_orders\"\x93\x01\n\x12ListOrdersResponse\x12>\n\x06orders\x18\x01 \x03(\x0b\x32&.xudrpc.ListOrdersResponse.OrdersEntryR\x06orders\x1a=\n\x0bOrdersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.xudrpc.Orders:\x02\x38\x01\"\x17\n\x15ListCurrenciesRequest\"8\n\x16ListCurrenciesResponse\x12\x1e\n\ncurrencies\x18\x01 \x03(\tR\ncurrencies\"\x12\n\x10ListPairsRequest\")\n\x11ListPairsResponse\x12\x14\n\x05pairs\x18\x01 \x03(\tR\x05pairs\"\x12\n\x10ListPeersRequest\"7\n\x11ListPeersResponse\x12\"\n\x05peers\x18\x01 \x03(\x0b\x32\x0c.xudrpc.PeerR\x05peers\"[\n\x0bLndChannels\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x05R\x06\x61\x63tive\x12\x1a\n\x08inactive\x18\x02 \x01(\x05R\x08inactive\x12\x18\n\x07pending\x18\x03 \x01(\x05R\x07pending\"\xce\x01\n\x07LndInfo\x12\x14\n\x05\x65rror\x18\x01 \x01(\tR\x05\x65rror\x12/\n\x08\x63hannels\x18\x02 \x01(\x0b\x32\x13.xudrpc.LndChannelsR\x08\x63hannels\x12\x16\n\x06\x63hains\x18\x03 \x03(\tR\x06\x63hains\x12 \n\x0b\x62lockheight\x18\x04 \x01(\x05R\x0b\x62lockheight\x12\x12\n\x04uris\x18\x05 \x03(\tR\x04uris\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\x12\x14\n\x05\x61lias\x18\x07 \x01(\tR\x05\x61lias\"\xb5\x02\n\x05Order\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\x04R\x08quantity\x12\x18\n\x07pair_id\x18\x03 \x01(\tR\x07pair_id\x12\x0e\n\x02id\x18\x04 \x01(\tR\x02id\x12$\n\x0cpeer_pub_key\x18\x05 \x01(\tH\x00R\x0cpeer_pub_key\x12\x1c\n\x08local_id\x18\x06 \x01(\tH\x00R\x08local_id\x12\x1e\n\ncreated_at\x18\x07 \x01(\x03R\ncreated_at\x12%\n\x04side\x18\x08 \x01(\x0e\x32\x11.xudrpc.OrderSideR\x04side\x12\"\n\x0cis_own_order\x18\t \x01(\x08R\x0cis_own_order\x12\x12\n\x04hold\x18\n \x01(\x04R\x04holdB\r\n\x0bown_or_peer\"\xc0\x01\n\x0cOrderRemoval\x12\x1a\n\x08quantity\x18\x01 \x01(\x04R\x08quantity\x12\x18\n\x07pair_id\x18\x02 \x01(\tR\x07pair_id\x12\x1a\n\x08order_id\x18\x03 \x01(\tR\x08order_id\x12\x1a\n\x08local_id\x18\x04 \x01(\tR\x08local_id\x12\"\n\x0cis_own_order\x18\x05 \x01(\x08R\x0cis_own_order\x12\x1e\n\nremoved_at\x18\x06 \x01(\x03R\nremoved_at\"h\n\x06Orders\x12-\n\nbuy_orders\x18\x01 \x03(\x0b\x32\r.xudrpc.OrderR\nbuy_orders\x12/\n\x0bsell_orders\x18\x02 \x03(\x0b\x32\r.xudrpc.OrderR\x0bsell_orders\"3\n\x0bOrdersCount\x12\x12\n\x04peer\x18\x01 \x01(\x05R\x04peer\x12\x10\n\x03own\x18\x02 \x01(\x05R\x03own\"\xe1\x02\n\x04Peer\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\"\n\x0cnode_pub_key\x18\x02 \x01(\tR\x0cnode_pub_key\x12@\n\x0clnd_pub_keys\x18\x03 \x03(\x0b\x32\x1c.xudrpc.Peer.LndPubKeysEntryR\x0clnd_pub_keys\x12\x18\n\x07inbound\x18\x04 \x01(\x08R\x07inbound\x12\x14\n\x05pairs\x18\x05 \x03(\tR\x05pairs\x12 \n\x0bxud_version\x18\x06 \x01(\tR\x0bxud_version\x12,\n\x11seconds_connected\x18\x07 \x01(\x05R\x11seconds_connected\x12&\n\x0eraiden_address\x18\x08 \x01(\tR\x0eraiden_address\x1a\x31\n\x0fLndPubKeysEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa2\x01\n\x11PlaceOrderRequest\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\x04R\x08quantity\x12\x18\n\x07pair_id\x18\x03 \x01(\tR\x07pair_id\x12\x1a\n\x08order_id\x18\x04 \x01(\tR\x08order_id\x12%\n\x04side\x18\x05 \x01(\x0e\x32\x11.xudrpc.OrderSideR\x04side\"\x80\x02\n\x12PlaceOrderResponse\x12\x39\n\x10internal_matches\x18\x01 \x03(\x0b\x32\r.xudrpc.OrderR\x10internal_matches\x12;\n\x0eswap_successes\x18\x02 \x03(\x0b\x32\x13.xudrpc.SwapSuccessR\x0eswap_successes\x12\x37\n\x0fremaining_order\x18\x03 \x01(\x0b\x32\r.xudrpc.OrderR\x0fremaining_order\x12\x39\n\rswap_failures\x18\x04 \x03(\x0b\x32\x13.xudrpc.SwapFailureR\rswap_failures\"\x84\x02\n\x0fPlaceOrderEvent\x12\x37\n\x0einternal_match\x18\x01 \x01(\x0b\x32\r.xudrpc.OrderH\x00R\x0einternal_match\x12\x39\n\x0cswap_success\x18\x02 \x01(\x0b\x32\x13.xudrpc.SwapSuccessH\x00R\x0cswap_success\x12\x39\n\x0fremaining_order\x18\x03 \x01(\x0b\x32\r.xudrpc.OrderH\x00R\x0fremaining_order\x12\x39\n\x0cswap_failure\x18\x04 \x01(\x0b\x32\x13.xudrpc.SwapFailureH\x00R\x0cswap_failureB\x07\n\x05\x65vent\"r\n\nRaidenInfo\x12\x14\n\x05\x65rror\x18\x01 \x01(\tR\x05\x65rror\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x1a\n\x08\x63hannels\x18\x03 \x01(\x05R\x08\x63hannels\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\"3\n\x15RemoveCurrencyRequest\x12\x1a\n\x08\x63urrency\x18\x01 \x01(\tR\x08\x63urrency\"\x18\n\x16RemoveCurrencyResponse\"L\n\x12RemoveOrderRequest\x12\x1a\n\x08order_id\x18\x01 \x01(\tR\x08order_id\x12\x1a\n\x08quantity\x18\x02 \x01(\x04R\x08quantity\"5\n\x13RemoveOrderResponse\x12\x1e\n\x10quantity_on_hold\x18\x01 \x01(\x04R\x04hold\"-\n\x11RemovePairRequest\x12\x18\n\x07pair_id\x18\x01 \x01(\tR\x07pair_id\"\x14\n\x12RemovePairResponse\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse\"9\n\x1bSubscribeAddedOrdersRequest\x12\x1a\n\x08\x65xisting\x18\x01 \x01(\x08R\x08\x65xisting\"\x1f\n\x1dSubscribeRemovedOrdersRequest\"=\n\x15SubscribeSwapsRequest\x12$\n\rinclude_taker\x18\x01 \x01(\x08R\rinclude_taker\"\xf5\x03\n\x0bSwapSuccess\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x1a\n\x08local_id\x18\x02 \x01(\tR\x08local_id\x12\x18\n\x07pair_id\x18\x03 \x01(\tR\x07pair_id\x12\x1a\n\x08quantity\x18\x04 \x01(\x04R\x08quantity\x12\x16\n\x06r_hash\x18\x05 \x01(\tR\x06r_hash\x12(\n\x0f\x61mount_received\x18\x08 \x01(\x03R\x0f\x61mount_received\x12 \n\x0b\x61mount_sent\x18\t \x01(\x03R\x0b\x61mount_sent\x12\"\n\x0cpeer_pub_key\x18\n \x01(\tR\x0cpeer_pub_key\x12,\n\x04role\x18\x0b \x01(\x0e\x32\x18.xudrpc.SwapSuccess.RoleR\x04role\x12,\n\x11\x63urrency_received\x18\x0c \x01(\tR\x11\x63urrency_received\x12$\n\rcurrency_sent\x18\r \x01(\tR\rcurrency_sent\x12\x1e\n\nr_preimage\x18\x0e \x01(\tR\nr_preimage\x12\x14\n\x05price\x18\x0f \x01(\x01R\x05price\x12$\n\rcomplete_time\x18\x10 \x01(\x03R\rcomplete_time\"\x1c\n\x04Role\x12\t\n\x05TAKER\x10\x00\x12\t\n\x05MAKER\x10\x01\"P\n\x0cUnbanRequest\x12\"\n\x0cnode_pub_key\x18\x01 \x01(\tR\x0cnode_pub_key\x12\x1c\n\treconnect\x18\x02 \x01(\x08R\treconnect\"\x0f\n\rUnbanResponse*\x1e\n\tOrderSide\x12\x07\n\x03\x42UY\x10\x00\x12\x08\n\x04SELL\x10\x01\x32\x98\x11\n\x03Xud\x12\x62\n\x0b\x41\x64\x64\x43urrency\x12\x1a.xudrpc.AddCurrencyRequest\x1a\x1b.xudrpc.AddCurrencyResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/addcurrency:\x01*\x12R\n\x07\x41\x64\x64Pair\x12\x16.xudrpc.AddPairRequest\x1a\x17.xudrpc.AddPairResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/addpair:\x01*\x12\x62\n\x0bRemoveOrder\x12\x1a.xudrpc.RemoveOrderRequest\x1a\x1b.xudrpc.RemoveOrderResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/removeorder:\x01*\x12k\n\x0e\x43hannelBalance\x12\x1d.xudrpc.ChannelBalanceRequest\x1a\x1e.xudrpc.ChannelBalanceResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/channelbalance\x12R\n\x07\x43onnect\x12\x16.xudrpc.ConnectRequest\x1a\x17.xudrpc.ConnectResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/connect:\x01*\x12\x42\n\x03\x42\x61n\x12\x12.xudrpc.BanRequest\x1a\x13.xudrpc.BanResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/v1/ban:\x01*\x12J\n\x05Unban\x12\x14.xudrpc.UnbanRequest\x1a\x15.xudrpc.UnbanResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v1/unban:\x01*\x12L\n\x07GetInfo\x12\x16.xudrpc.GetInfoRequest\x1a\x17.xudrpc.GetInfoResponse\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/info\x12\\\n\x0bGetNodeInfo\x12\x1a.xudrpc.GetNodeInfoRequest\x1a\x1b.xudrpc.GetNodeInfoResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/nodeinfo\x12W\n\nListOrders\x12\x19.xudrpc.ListOrdersRequest\x1a\x1a.xudrpc.ListOrdersResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/orders\x12g\n\x0eListCurrencies\x12\x1d.xudrpc.ListCurrenciesRequest\x1a\x1e.xudrpc.ListCurrenciesResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/currencies\x12S\n\tListPairs\x12\x18.xudrpc.ListPairsRequest\x1a\x19.xudrpc.ListPairsResponse\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/pairs\x12S\n\tListPeers\x12\x18.xudrpc.ListPeersRequest\x1a\x19.xudrpc.ListPeersResponse\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/peers\x12]\n\nPlaceOrder\x12\x19.xudrpc.PlaceOrderRequest\x1a\x17.xudrpc.PlaceOrderEvent\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/placeorder:\x01*0\x01\x12\x66\n\x0ePlaceOrderSync\x12\x19.xudrpc.PlaceOrderRequest\x1a\x1a.xudrpc.PlaceOrderResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/placeordersync:\x01*\x12Z\n\x0b\x45xecuteSwap\x12\x1a.xudrpc.ExecuteSwapRequest\x1a\x13.xudrpc.SwapSuccess\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/executeswap:\x01*\x12n\n\x0eRemoveCurrency\x12\x1d.xudrpc.RemoveCurrencyRequest\x1a\x1e.xudrpc.RemoveCurrencyResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/removecurrency:\x01*\x12^\n\nRemovePair\x12\x19.xudrpc.RemovePairRequest\x1a\x1a.xudrpc.RemovePairResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/removepair:\x01*\x12V\n\x08Shutdown\x12\x17.xudrpc.ShutdownRequest\x1a\x18.xudrpc.ShutdownResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/shutdown:\x01*\x12n\n\x14SubscribeAddedOrders\x12#.xudrpc.SubscribeAddedOrdersRequest\x1a\r.xudrpc.Order\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/subscribeaddedorders0\x01\x12{\n\x16SubscribeRemovedOrders\x12%.xudrpc.SubscribeRemovedOrdersRequest\x1a\x14.xudrpc.OrderRemoval\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/subscriberemovedorders0\x01\x12\x62\n\x0eSubscribeSwaps\x12\x1d.xudrpc.SubscribeSwapsRequest\x1a\x13.xudrpc.SwapSuccess\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/subscribeswaps0\x01\x12p\n\x15SubscribeSwapFailures\x12\x1d.xudrpc.SubscribeSwapsRequest\x1a\x13.xudrpc.SwapFailure\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/subscribeswapfailures0\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_ORDERSIDE = _descriptor.EnumDescriptor(
  name='OrderSide',
  full_name='xudrpc.OrderSide',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SELL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5391,
  serialized_end=5421,
)
_sym_db.RegisterEnumDescriptor(_ORDERSIDE)

OrderSide = enum_type_wrapper.EnumTypeWrapper(_ORDERSIDE)
BUY = 0
SELL = 1


_ADDCURRENCYREQUEST_SWAPCLIENT = _descriptor.EnumDescriptor(
  name='SwapClient',
  full_name='xudrpc.AddCurrencyRequest.SwapClient',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LND', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAIDEN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=255,
  serialized_end=288,
)
_sym_db.RegisterEnumDescriptor(_ADDCURRENCYREQUEST_SWAPCLIENT)

_SWAPSUCCESS_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='xudrpc.SwapSuccess.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TAKER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAKER', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5262,
  serialized_end=5290,
)
_sym_db.RegisterEnumDescriptor(_SWAPSUCCESS_ROLE)


_ADDCURRENCYREQUEST = _descriptor.Descriptor(
  name='AddCurrencyRequest',
  full_name='xudrpc.AddCurrencyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='xudrpc.AddCurrencyRequest.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currency', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_client', full_name='xudrpc.AddCurrencyRequest.swap_client', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='swap_client', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_address', full_name='xudrpc.AddCurrencyRequest.token_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='token_address', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='xudrpc.AddCurrencyRequest.decimal_places', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='decimal_places', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADDCURRENCYREQUEST_SWAPCLIENT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=288,
)


_ADDCURRENCYRESPONSE = _descriptor.Descriptor(
  name='AddCurrencyResponse',
  full_name='xudrpc.AddCurrencyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=311,
)


_ADDPAIRREQUEST = _descriptor.Descriptor(
  name='AddPairRequest',
  full_name='xudrpc.AddPairRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_currency', full_name='xudrpc.AddPairRequest.base_currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='base_currency', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quote_currency', full_name='xudrpc.AddPairRequest.quote_currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quote_currency', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=407,
)


_ADDPAIRRESPONSE = _descriptor.Descriptor(
  name='AddPairResponse',
  full_name='xudrpc.AddPairResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=409,
  serialized_end=426,
)


_BANREQUEST = _descriptor.Descriptor(
  name='BanRequest',
  full_name='xudrpc.BanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pub_key', full_name='xudrpc.BanRequest.node_pub_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_pub_key', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=476,
)


_BANRESPONSE = _descriptor.Descriptor(
  name='BanResponse',
  full_name='xudrpc.BanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=491,
)


_CHANNELBALANCE = _descriptor.Descriptor(
  name='ChannelBalance',
  full_name='xudrpc.ChannelBalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='xudrpc.ChannelBalance.balance', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='balance', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending_open_balance', full_name='xudrpc.ChannelBalance.pending_open_balance', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pending_open_balance', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=587,
)


_CHANNELBALANCEREQUEST = _descriptor.Descriptor(
  name='ChannelBalanceRequest',
  full_name='xudrpc.ChannelBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='xudrpc.ChannelBalanceRequest.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currency', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=640,
)


_CHANNELBALANCERESPONSE_BALANCESENTRY = _descriptor.Descriptor(
  name='BalancesEntry',
  full_name='xudrpc.ChannelBalanceResponse.BalancesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xudrpc.ChannelBalanceResponse.BalancesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xudrpc.ChannelBalanceResponse.BalancesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=812,
)

_CHANNELBALANCERESPONSE = _descriptor.Descriptor(
  name='ChannelBalanceResponse',
  full_name='xudrpc.ChannelBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='balances', full_name='xudrpc.ChannelBalanceResponse.balances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orders', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELBALANCERESPONSE_BALANCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=812,
)


_CONNECTREQUEST = _descriptor.Descriptor(
  name='ConnectRequest',
  full_name='xudrpc.ConnectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_uri', full_name='xudrpc.ConnectRequest.node_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_uri', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=858,
)


_CONNECTRESPONSE = _descriptor.Descriptor(
  name='ConnectResponse',
  full_name='xudrpc.ConnectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=877,
)


_EXECUTESWAPREQUEST = _descriptor.Descriptor(
  name='ExecuteSwapRequest',
  full_name='xudrpc.ExecuteSwapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='xudrpc.ExecuteSwapRequest.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='order_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.ExecuteSwapRequest.pair_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_pub_key', full_name='xudrpc.ExecuteSwapRequest.peer_pub_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peer_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.ExecuteSwapRequest.quantity', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=1018,
)


_SWAPFAILURE = _descriptor.Descriptor(
  name='SwapFailure',
  full_name='xudrpc.SwapFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='xudrpc.SwapFailure.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='order_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.SwapFailure.pair_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.SwapFailure.quantity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_pub_key', full_name='xudrpc.SwapFailure.peer_pub_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peer_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure_reason', full_name='xudrpc.SwapFailure.failure_reason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='failure_reason', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1192,
)


_GETINFOREQUEST = _descriptor.Descriptor(
  name='GetInfoRequest',
  full_name='xudrpc.GetInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1210,
)


_GETINFORESPONSE_LNDENTRY = _descriptor.Descriptor(
  name='LndEntry',
  full_name='xudrpc.GetInfoResponse.LndEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xudrpc.GetInfoResponse.LndEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xudrpc.GetInfoResponse.LndEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1574,
)

_GETINFORESPONSE = _descriptor.Descriptor(
  name='GetInfoResponse',
  full_name='xudrpc.GetInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='xudrpc.GetInfoResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_pub_key', full_name='xudrpc.GetInfoResponse.node_pub_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uris', full_name='xudrpc.GetInfoResponse.uris', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uris', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_peers', full_name='xudrpc.GetInfoResponse.num_peers', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='num_peers', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_pairs', full_name='xudrpc.GetInfoResponse.num_pairs', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='num_pairs', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orders', full_name='xudrpc.GetInfoResponse.orders', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orders', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lnd', full_name='xudrpc.GetInfoResponse.lnd', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lnd', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raiden', full_name='xudrpc.GetInfoResponse.raiden', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='raiden', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETINFORESPONSE_LNDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1574,
)


_GETNODEINFOREQUEST = _descriptor.Descriptor(
  name='GetNodeInfoRequest',
  full_name='xudrpc.GetNodeInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pub_key', full_name='xudrpc.GetNodeInfoRequest.node_pub_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_pub_key', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1576,
  serialized_end=1632,
)


_GETNODEINFORESPONSE = _descriptor.Descriptor(
  name='GetNodeInfoResponse',
  full_name='xudrpc.GetNodeInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reputationScore', full_name='xudrpc.GetNodeInfoResponse.reputationScore', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reputation', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banned', full_name='xudrpc.GetNodeInfoResponse.banned', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='banned', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1716,
)


_LISTORDERSREQUEST = _descriptor.Descriptor(
  name='ListOrdersRequest',
  full_name='xudrpc.ListOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.ListOrdersRequest.pair_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_own_orders', full_name='xudrpc.ListOrdersRequest.include_own_orders', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='include_own_orders', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1718,
  serialized_end=1811,
)


_LISTORDERSRESPONSE_ORDERSENTRY = _descriptor.Descriptor(
  name='OrdersEntry',
  full_name='xudrpc.ListOrdersResponse.OrdersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xudrpc.ListOrdersResponse.OrdersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xudrpc.ListOrdersResponse.OrdersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1900,
  serialized_end=1961,
)

_LISTORDERSRESPONSE = _descriptor.Descriptor(
  name='ListOrdersResponse',
  full_name='xudrpc.ListOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='xudrpc.ListOrdersResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orders', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTORDERSRESPONSE_ORDERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1814,
  serialized_end=1961,
)


_LISTCURRENCIESREQUEST = _descriptor.Descriptor(
  name='ListCurrenciesRequest',
  full_name='xudrpc.ListCurrenciesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1963,
  serialized_end=1986,
)


_LISTCURRENCIESRESPONSE = _descriptor.Descriptor(
  name='ListCurrenciesResponse',
  full_name='xudrpc.ListCurrenciesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currencies', full_name='xudrpc.ListCurrenciesResponse.currencies', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currencies', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1988,
  serialized_end=2044,
)


_LISTPAIRSREQUEST = _descriptor.Descriptor(
  name='ListPairsRequest',
  full_name='xudrpc.ListPairsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2064,
)


_LISTPAIRSRESPONSE = _descriptor.Descriptor(
  name='ListPairsResponse',
  full_name='xudrpc.ListPairsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pairs', full_name='xudrpc.ListPairsResponse.pairs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pairs', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2066,
  serialized_end=2107,
)


_LISTPEERSREQUEST = _descriptor.Descriptor(
  name='ListPeersRequest',
  full_name='xudrpc.ListPeersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2109,
  serialized_end=2127,
)


_LISTPEERSRESPONSE = _descriptor.Descriptor(
  name='ListPeersResponse',
  full_name='xudrpc.ListPeersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='xudrpc.ListPeersResponse.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2129,
  serialized_end=2184,
)


_LNDCHANNELS = _descriptor.Descriptor(
  name='LndChannels',
  full_name='xudrpc.LndChannels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='xudrpc.LndChannels.active', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='active', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inactive', full_name='xudrpc.LndChannels.inactive', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inactive', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending', full_name='xudrpc.LndChannels.pending', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pending', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2186,
  serialized_end=2277,
)


_LNDINFO = _descriptor.Descriptor(
  name='LndInfo',
  full_name='xudrpc.LndInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xudrpc.LndInfo.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='xudrpc.LndInfo.channels', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='channels', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chains', full_name='xudrpc.LndInfo.chains', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='chains', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockheight', full_name='xudrpc.LndInfo.blockheight', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='blockheight', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uris', full_name='xudrpc.LndInfo.uris', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uris', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='xudrpc.LndInfo.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='xudrpc.LndInfo.alias', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='alias', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2280,
  serialized_end=2486,
)


_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='xudrpc.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='xudrpc.Order.price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.Order.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.Order.pair_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='xudrpc.Order.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_pub_key', full_name='xudrpc.Order.peer_pub_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peer_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_id', full_name='xudrpc.Order.local_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='local_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='xudrpc.Order.created_at', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='created_at', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='side', full_name='xudrpc.Order.side', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='side', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_own_order', full_name='xudrpc.Order.is_own_order', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='is_own_order', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hold', full_name='xudrpc.Order.hold', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hold', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='own_or_peer', full_name='xudrpc.Order.own_or_peer',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2489,
  serialized_end=2798,
)


_ORDERREMOVAL = _descriptor.Descriptor(
  name='OrderRemoval',
  full_name='xudrpc.OrderRemoval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.OrderRemoval.quantity', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.OrderRemoval.pair_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='xudrpc.OrderRemoval.order_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='order_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_id', full_name='xudrpc.OrderRemoval.local_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='local_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_own_order', full_name='xudrpc.OrderRemoval.is_own_order', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='is_own_order', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_at', full_name='xudrpc.OrderRemoval.removed_at', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='removed_at', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2801,
  serialized_end=2993,
)


_ORDERS = _descriptor.Descriptor(
  name='Orders',
  full_name='xudrpc.Orders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='buy_orders', full_name='xudrpc.Orders.buy_orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='buy_orders', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sell_orders', full_name='xudrpc.Orders.sell_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sell_orders', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2995,
  serialized_end=3099,
)


_ORDERSCOUNT = _descriptor.Descriptor(
  name='OrdersCount',
  full_name='xudrpc.OrdersCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='xudrpc.OrdersCount.peer', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peer', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='own', full_name='xudrpc.OrdersCount.own', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='own', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3101,
  serialized_end=3152,
)


_PEER_LNDPUBKEYSENTRY = _descriptor.Descriptor(
  name='LndPubKeysEntry',
  full_name='xudrpc.Peer.LndPubKeysEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xudrpc.Peer.LndPubKeysEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xudrpc.Peer.LndPubKeysEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3459,
  serialized_end=3508,
)

_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='xudrpc.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='xudrpc.Peer.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_pub_key', full_name='xudrpc.Peer.node_pub_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lnd_pub_keys', full_name='xudrpc.Peer.lnd_pub_keys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lnd_pub_keys', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inbound', full_name='xudrpc.Peer.inbound', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inbound', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='xudrpc.Peer.pairs', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pairs', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xud_version', full_name='xudrpc.Peer.xud_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='xud_version', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seconds_connected', full_name='xudrpc.Peer.seconds_connected', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='seconds_connected', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raiden_address', full_name='xudrpc.Peer.raiden_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='raiden_address', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PEER_LNDPUBKEYSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3155,
  serialized_end=3508,
)


_PLACEORDERREQUEST = _descriptor.Descriptor(
  name='PlaceOrderRequest',
  full_name='xudrpc.PlaceOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='xudrpc.PlaceOrderRequest.price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.PlaceOrderRequest.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.PlaceOrderRequest.pair_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='xudrpc.PlaceOrderRequest.order_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='order_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='side', full_name='xudrpc.PlaceOrderRequest.side', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='side', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3511,
  serialized_end=3673,
)


_PLACEORDERRESPONSE = _descriptor.Descriptor(
  name='PlaceOrderResponse',
  full_name='xudrpc.PlaceOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_matches', full_name='xudrpc.PlaceOrderResponse.internal_matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internal_matches', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_successes', full_name='xudrpc.PlaceOrderResponse.swap_successes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='swap_successes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remaining_order', full_name='xudrpc.PlaceOrderResponse.remaining_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='remaining_order', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_failures', full_name='xudrpc.PlaceOrderResponse.swap_failures', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='swap_failures', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3676,
  serialized_end=3932,
)


_PLACEORDEREVENT = _descriptor.Descriptor(
  name='PlaceOrderEvent',
  full_name='xudrpc.PlaceOrderEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_match', full_name='xudrpc.PlaceOrderEvent.internal_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internal_match', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_success', full_name='xudrpc.PlaceOrderEvent.swap_success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='swap_success', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remaining_order', full_name='xudrpc.PlaceOrderEvent.remaining_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='remaining_order', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_failure', full_name='xudrpc.PlaceOrderEvent.swap_failure', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='swap_failure', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='xudrpc.PlaceOrderEvent.event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3935,
  serialized_end=4195,
)


_RAIDENINFO = _descriptor.Descriptor(
  name='RaidenInfo',
  full_name='xudrpc.RaidenInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xudrpc.RaidenInfo.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='xudrpc.RaidenInfo.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='xudrpc.RaidenInfo.channels', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='channels', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='xudrpc.RaidenInfo.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4197,
  serialized_end=4311,
)


_REMOVECURRENCYREQUEST = _descriptor.Descriptor(
  name='RemoveCurrencyRequest',
  full_name='xudrpc.RemoveCurrencyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='xudrpc.RemoveCurrencyRequest.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currency', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4313,
  serialized_end=4364,
)


_REMOVECURRENCYRESPONSE = _descriptor.Descriptor(
  name='RemoveCurrencyResponse',
  full_name='xudrpc.RemoveCurrencyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4366,
  serialized_end=4390,
)


_REMOVEORDERREQUEST = _descriptor.Descriptor(
  name='RemoveOrderRequest',
  full_name='xudrpc.RemoveOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='xudrpc.RemoveOrderRequest.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='order_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.RemoveOrderRequest.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4392,
  serialized_end=4468,
)


_REMOVEORDERRESPONSE = _descriptor.Descriptor(
  name='RemoveOrderResponse',
  full_name='xudrpc.RemoveOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantity_on_hold', full_name='xudrpc.RemoveOrderResponse.quantity_on_hold', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hold', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4470,
  serialized_end=4523,
)


_REMOVEPAIRREQUEST = _descriptor.Descriptor(
  name='RemovePairRequest',
  full_name='xudrpc.RemovePairRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.RemovePairRequest.pair_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4525,
  serialized_end=4570,
)


_REMOVEPAIRRESPONSE = _descriptor.Descriptor(
  name='RemovePairResponse',
  full_name='xudrpc.RemovePairResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4572,
  serialized_end=4592,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='xudrpc.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4594,
  serialized_end=4611,
)


_SHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='ShutdownResponse',
  full_name='xudrpc.ShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4613,
  serialized_end=4631,
)


_SUBSCRIBEADDEDORDERSREQUEST = _descriptor.Descriptor(
  name='SubscribeAddedOrdersRequest',
  full_name='xudrpc.SubscribeAddedOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='existing', full_name='xudrpc.SubscribeAddedOrdersRequest.existing', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='existing', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4633,
  serialized_end=4690,
)


_SUBSCRIBEREMOVEDORDERSREQUEST = _descriptor.Descriptor(
  name='SubscribeRemovedOrdersRequest',
  full_name='xudrpc.SubscribeRemovedOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4692,
  serialized_end=4723,
)


_SUBSCRIBESWAPSREQUEST = _descriptor.Descriptor(
  name='SubscribeSwapsRequest',
  full_name='xudrpc.SubscribeSwapsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_taker', full_name='xudrpc.SubscribeSwapsRequest.include_taker', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='include_taker', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4725,
  serialized_end=4786,
)


_SWAPSUCCESS = _descriptor.Descriptor(
  name='SwapSuccess',
  full_name='xudrpc.SwapSuccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='xudrpc.SwapSuccess.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_id', full_name='xudrpc.SwapSuccess.local_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='local_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pair_id', full_name='xudrpc.SwapSuccess.pair_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pair_id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='xudrpc.SwapSuccess.quantity', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r_hash', full_name='xudrpc.SwapSuccess.r_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='r_hash', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_received', full_name='xudrpc.SwapSuccess.amount_received', index=5,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount_received', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_sent', full_name='xudrpc.SwapSuccess.amount_sent', index=6,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount_sent', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_pub_key', full_name='xudrpc.SwapSuccess.peer_pub_key', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peer_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='xudrpc.SwapSuccess.role', index=8,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='role', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_received', full_name='xudrpc.SwapSuccess.currency_received', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currency_received', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_sent', full_name='xudrpc.SwapSuccess.currency_sent', index=10,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currency_sent', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r_preimage', full_name='xudrpc.SwapSuccess.r_preimage', index=11,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='r_preimage', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='xudrpc.SwapSuccess.price', index=12,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='complete_time', full_name='xudrpc.SwapSuccess.complete_time', index=13,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='complete_time', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SWAPSUCCESS_ROLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4789,
  serialized_end=5290,
)


_UNBANREQUEST = _descriptor.Descriptor(
  name='UnbanRequest',
  full_name='xudrpc.UnbanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pub_key', full_name='xudrpc.UnbanRequest.node_pub_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_pub_key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reconnect', full_name='xudrpc.UnbanRequest.reconnect', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reconnect', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5292,
  serialized_end=5372,
)


_UNBANRESPONSE = _descriptor.Descriptor(
  name='UnbanResponse',
  full_name='xudrpc.UnbanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5374,
  serialized_end=5389,
)

_ADDCURRENCYREQUEST.fields_by_name['swap_client'].enum_type = _ADDCURRENCYREQUEST_SWAPCLIENT
_ADDCURRENCYREQUEST_SWAPCLIENT.containing_type = _ADDCURRENCYREQUEST
_CHANNELBALANCERESPONSE_BALANCESENTRY.fields_by_name['value'].message_type = _CHANNELBALANCE
_CHANNELBALANCERESPONSE_BALANCESENTRY.containing_type = _CHANNELBALANCERESPONSE
_CHANNELBALANCERESPONSE.fields_by_name['balances'].message_type = _CHANNELBALANCERESPONSE_BALANCESENTRY
_GETINFORESPONSE_LNDENTRY.fields_by_name['value'].message_type = _LNDINFO
_GETINFORESPONSE_LNDENTRY.containing_type = _GETINFORESPONSE
_GETINFORESPONSE.fields_by_name['orders'].message_type = _ORDERSCOUNT
_GETINFORESPONSE.fields_by_name['lnd'].message_type = _GETINFORESPONSE_LNDENTRY
_GETINFORESPONSE.fields_by_name['raiden'].message_type = _RAIDENINFO
_LISTORDERSRESPONSE_ORDERSENTRY.fields_by_name['value'].message_type = _ORDERS
_LISTORDERSRESPONSE_ORDERSENTRY.containing_type = _LISTORDERSRESPONSE
_LISTORDERSRESPONSE.fields_by_name['orders'].message_type = _LISTORDERSRESPONSE_ORDERSENTRY
_LISTPEERSRESPONSE.fields_by_name['peers'].message_type = _PEER
_LNDINFO.fields_by_name['channels'].message_type = _LNDCHANNELS
_ORDER.fields_by_name['side'].enum_type = _ORDERSIDE
_ORDER.oneofs_by_name['own_or_peer'].fields.append(
  _ORDER.fields_by_name['peer_pub_key'])
_ORDER.fields_by_name['peer_pub_key'].containing_oneof = _ORDER.oneofs_by_name['own_or_peer']
_ORDER.oneofs_by_name['own_or_peer'].fields.append(
  _ORDER.fields_by_name['local_id'])
_ORDER.fields_by_name['local_id'].containing_oneof = _ORDER.oneofs_by_name['own_or_peer']
_ORDERS.fields_by_name['buy_orders'].message_type = _ORDER
_ORDERS.fields_by_name['sell_orders'].message_type = _ORDER
_PEER_LNDPUBKEYSENTRY.containing_type = _PEER
_PEER.fields_by_name['lnd_pub_keys'].message_type = _PEER_LNDPUBKEYSENTRY
_PLACEORDERREQUEST.fields_by_name['side'].enum_type = _ORDERSIDE
_PLACEORDERRESPONSE.fields_by_name['internal_matches'].message_type = _ORDER
_PLACEORDERRESPONSE.fields_by_name['swap_successes'].message_type = _SWAPSUCCESS
_PLACEORDERRESPONSE.fields_by_name['remaining_order'].message_type = _ORDER
_PLACEORDERRESPONSE.fields_by_name['swap_failures'].message_type = _SWAPFAILURE
_PLACEORDEREVENT.fields_by_name['internal_match'].message_type = _ORDER
_PLACEORDEREVENT.fields_by_name['swap_success'].message_type = _SWAPSUCCESS
_PLACEORDEREVENT.fields_by_name['remaining_order'].message_type = _ORDER
_PLACEORDEREVENT.fields_by_name['swap_failure'].message_type = _SWAPFAILURE
_PLACEORDEREVENT.oneofs_by_name['event'].fields.append(
  _PLACEORDEREVENT.fields_by_name['internal_match'])
_PLACEORDEREVENT.fields_by_name['internal_match'].containing_oneof = _PLACEORDEREVENT.oneofs_by_name['event']
_PLACEORDEREVENT.oneofs_by_name['event'].fields.append(
  _PLACEORDEREVENT.fields_by_name['swap_success'])
_PLACEORDEREVENT.fields_by_name['swap_success'].containing_oneof = _PLACEORDEREVENT.oneofs_by_name['event']
_PLACEORDEREVENT.oneofs_by_name['event'].fields.append(
  _PLACEORDEREVENT.fields_by_name['remaining_order'])
_PLACEORDEREVENT.fields_by_name['remaining_order'].containing_oneof = _PLACEORDEREVENT.oneofs_by_name['event']
_PLACEORDEREVENT.oneofs_by_name['event'].fields.append(
  _PLACEORDEREVENT.fields_by_name['swap_failure'])
_PLACEORDEREVENT.fields_by_name['swap_failure'].containing_oneof = _PLACEORDEREVENT.oneofs_by_name['event']
_SWAPSUCCESS.fields_by_name['role'].enum_type = _SWAPSUCCESS_ROLE
_SWAPSUCCESS_ROLE.containing_type = _SWAPSUCCESS
DESCRIPTOR.message_types_by_name['AddCurrencyRequest'] = _ADDCURRENCYREQUEST
DESCRIPTOR.message_types_by_name['AddCurrencyResponse'] = _ADDCURRENCYRESPONSE
DESCRIPTOR.message_types_by_name['AddPairRequest'] = _ADDPAIRREQUEST
DESCRIPTOR.message_types_by_name['AddPairResponse'] = _ADDPAIRRESPONSE
DESCRIPTOR.message_types_by_name['BanRequest'] = _BANREQUEST
DESCRIPTOR.message_types_by_name['BanResponse'] = _BANRESPONSE
DESCRIPTOR.message_types_by_name['ChannelBalance'] = _CHANNELBALANCE
DESCRIPTOR.message_types_by_name['ChannelBalanceRequest'] = _CHANNELBALANCEREQUEST
DESCRIPTOR.message_types_by_name['ChannelBalanceResponse'] = _CHANNELBALANCERESPONSE
DESCRIPTOR.message_types_by_name['ConnectRequest'] = _CONNECTREQUEST
DESCRIPTOR.message_types_by_name['ConnectResponse'] = _CONNECTRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteSwapRequest'] = _EXECUTESWAPREQUEST
DESCRIPTOR.message_types_by_name['SwapFailure'] = _SWAPFAILURE
DESCRIPTOR.message_types_by_name['GetInfoRequest'] = _GETINFOREQUEST
DESCRIPTOR.message_types_by_name['GetInfoResponse'] = _GETINFORESPONSE
DESCRIPTOR.message_types_by_name['GetNodeInfoRequest'] = _GETNODEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetNodeInfoResponse'] = _GETNODEINFORESPONSE
DESCRIPTOR.message_types_by_name['ListOrdersRequest'] = _LISTORDERSREQUEST
DESCRIPTOR.message_types_by_name['ListOrdersResponse'] = _LISTORDERSRESPONSE
DESCRIPTOR.message_types_by_name['ListCurrenciesRequest'] = _LISTCURRENCIESREQUEST
DESCRIPTOR.message_types_by_name['ListCurrenciesResponse'] = _LISTCURRENCIESRESPONSE
DESCRIPTOR.message_types_by_name['ListPairsRequest'] = _LISTPAIRSREQUEST
DESCRIPTOR.message_types_by_name['ListPairsResponse'] = _LISTPAIRSRESPONSE
DESCRIPTOR.message_types_by_name['ListPeersRequest'] = _LISTPEERSREQUEST
DESCRIPTOR.message_types_by_name['ListPeersResponse'] = _LISTPEERSRESPONSE
DESCRIPTOR.message_types_by_name['LndChannels'] = _LNDCHANNELS
DESCRIPTOR.message_types_by_name['LndInfo'] = _LNDINFO
DESCRIPTOR.message_types_by_name['Order'] = _ORDER
DESCRIPTOR.message_types_by_name['OrderRemoval'] = _ORDERREMOVAL
DESCRIPTOR.message_types_by_name['Orders'] = _ORDERS
DESCRIPTOR.message_types_by_name['OrdersCount'] = _ORDERSCOUNT
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
DESCRIPTOR.message_types_by_name['PlaceOrderRequest'] = _PLACEORDERREQUEST
DESCRIPTOR.message_types_by_name['PlaceOrderResponse'] = _PLACEORDERRESPONSE
DESCRIPTOR.message_types_by_name['PlaceOrderEvent'] = _PLACEORDEREVENT
DESCRIPTOR.message_types_by_name['RaidenInfo'] = _RAIDENINFO
DESCRIPTOR.message_types_by_name['RemoveCurrencyRequest'] = _REMOVECURRENCYREQUEST
DESCRIPTOR.message_types_by_name['RemoveCurrencyResponse'] = _REMOVECURRENCYRESPONSE
DESCRIPTOR.message_types_by_name['RemoveOrderRequest'] = _REMOVEORDERREQUEST
DESCRIPTOR.message_types_by_name['RemoveOrderResponse'] = _REMOVEORDERRESPONSE
DESCRIPTOR.message_types_by_name['RemovePairRequest'] = _REMOVEPAIRREQUEST
DESCRIPTOR.message_types_by_name['RemovePairResponse'] = _REMOVEPAIRRESPONSE
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownResponse'] = _SHUTDOWNRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeAddedOrdersRequest'] = _SUBSCRIBEADDEDORDERSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRemovedOrdersRequest'] = _SUBSCRIBEREMOVEDORDERSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeSwapsRequest'] = _SUBSCRIBESWAPSREQUEST
DESCRIPTOR.message_types_by_name['SwapSuccess'] = _SWAPSUCCESS
DESCRIPTOR.message_types_by_name['UnbanRequest'] = _UNBANREQUEST
DESCRIPTOR.message_types_by_name['UnbanResponse'] = _UNBANRESPONSE
DESCRIPTOR.enum_types_by_name['OrderSide'] = _ORDERSIDE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AddCurrencyRequest = _reflection.GeneratedProtocolMessageType('AddCurrencyRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDCURRENCYREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.AddCurrencyRequest)
  ))
_sym_db.RegisterMessage(AddCurrencyRequest)

AddCurrencyResponse = _reflection.GeneratedProtocolMessageType('AddCurrencyResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDCURRENCYRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.AddCurrencyResponse)
  ))
_sym_db.RegisterMessage(AddCurrencyResponse)

AddPairRequest = _reflection.GeneratedProtocolMessageType('AddPairRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDPAIRREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.AddPairRequest)
  ))
_sym_db.RegisterMessage(AddPairRequest)

AddPairResponse = _reflection.GeneratedProtocolMessageType('AddPairResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDPAIRRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.AddPairResponse)
  ))
_sym_db.RegisterMessage(AddPairResponse)

BanRequest = _reflection.GeneratedProtocolMessageType('BanRequest', (_message.Message,), dict(
  DESCRIPTOR = _BANREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.BanRequest)
  ))
_sym_db.RegisterMessage(BanRequest)

BanResponse = _reflection.GeneratedProtocolMessageType('BanResponse', (_message.Message,), dict(
  DESCRIPTOR = _BANRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.BanResponse)
  ))
_sym_db.RegisterMessage(BanResponse)

ChannelBalance = _reflection.GeneratedProtocolMessageType('ChannelBalance', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELBALANCE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ChannelBalance)
  ))
_sym_db.RegisterMessage(ChannelBalance)

ChannelBalanceRequest = _reflection.GeneratedProtocolMessageType('ChannelBalanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELBALANCEREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ChannelBalanceRequest)
  ))
_sym_db.RegisterMessage(ChannelBalanceRequest)

ChannelBalanceResponse = _reflection.GeneratedProtocolMessageType('ChannelBalanceResponse', (_message.Message,), dict(

  BalancesEntry = _reflection.GeneratedProtocolMessageType('BalancesEntry', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELBALANCERESPONSE_BALANCESENTRY,
    __module__ = 'xurpc_pb2'
    # @@protoc_insertion_point(class_scope:xudrpc.ChannelBalanceResponse.BalancesEntry)
    ))
  ,
  DESCRIPTOR = _CHANNELBALANCERESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ChannelBalanceResponse)
  ))
_sym_db.RegisterMessage(ChannelBalanceResponse)
_sym_db.RegisterMessage(ChannelBalanceResponse.BalancesEntry)

ConnectRequest = _reflection.GeneratedProtocolMessageType('ConnectRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ConnectRequest)
  ))
_sym_db.RegisterMessage(ConnectRequest)

ConnectResponse = _reflection.GeneratedProtocolMessageType('ConnectResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ConnectResponse)
  ))
_sym_db.RegisterMessage(ConnectResponse)

ExecuteSwapRequest = _reflection.GeneratedProtocolMessageType('ExecuteSwapRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTESWAPREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ExecuteSwapRequest)
  ))
_sym_db.RegisterMessage(ExecuteSwapRequest)

SwapFailure = _reflection.GeneratedProtocolMessageType('SwapFailure', (_message.Message,), dict(
  DESCRIPTOR = _SWAPFAILURE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.SwapFailure)
  ))
_sym_db.RegisterMessage(SwapFailure)

GetInfoRequest = _reflection.GeneratedProtocolMessageType('GetInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINFOREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.GetInfoRequest)
  ))
_sym_db.RegisterMessage(GetInfoRequest)

GetInfoResponse = _reflection.GeneratedProtocolMessageType('GetInfoResponse', (_message.Message,), dict(

  LndEntry = _reflection.GeneratedProtocolMessageType('LndEntry', (_message.Message,), dict(
    DESCRIPTOR = _GETINFORESPONSE_LNDENTRY,
    __module__ = 'xurpc_pb2'
    # @@protoc_insertion_point(class_scope:xudrpc.GetInfoResponse.LndEntry)
    ))
  ,
  DESCRIPTOR = _GETINFORESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.GetInfoResponse)
  ))
_sym_db.RegisterMessage(GetInfoResponse)
_sym_db.RegisterMessage(GetInfoResponse.LndEntry)

GetNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetNodeInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETNODEINFOREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.GetNodeInfoRequest)
  ))
_sym_db.RegisterMessage(GetNodeInfoRequest)

GetNodeInfoResponse = _reflection.GeneratedProtocolMessageType('GetNodeInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETNODEINFORESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.GetNodeInfoResponse)
  ))
_sym_db.RegisterMessage(GetNodeInfoResponse)

ListOrdersRequest = _reflection.GeneratedProtocolMessageType('ListOrdersRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTORDERSREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListOrdersRequest)
  ))
_sym_db.RegisterMessage(ListOrdersRequest)

ListOrdersResponse = _reflection.GeneratedProtocolMessageType('ListOrdersResponse', (_message.Message,), dict(

  OrdersEntry = _reflection.GeneratedProtocolMessageType('OrdersEntry', (_message.Message,), dict(
    DESCRIPTOR = _LISTORDERSRESPONSE_ORDERSENTRY,
    __module__ = 'xurpc_pb2'
    # @@protoc_insertion_point(class_scope:xudrpc.ListOrdersResponse.OrdersEntry)
    ))
  ,
  DESCRIPTOR = _LISTORDERSRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListOrdersResponse)
  ))
_sym_db.RegisterMessage(ListOrdersResponse)
_sym_db.RegisterMessage(ListOrdersResponse.OrdersEntry)

ListCurrenciesRequest = _reflection.GeneratedProtocolMessageType('ListCurrenciesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTCURRENCIESREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListCurrenciesRequest)
  ))
_sym_db.RegisterMessage(ListCurrenciesRequest)

ListCurrenciesResponse = _reflection.GeneratedProtocolMessageType('ListCurrenciesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCURRENCIESRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListCurrenciesResponse)
  ))
_sym_db.RegisterMessage(ListCurrenciesResponse)

ListPairsRequest = _reflection.GeneratedProtocolMessageType('ListPairsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPAIRSREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListPairsRequest)
  ))
_sym_db.RegisterMessage(ListPairsRequest)

ListPairsResponse = _reflection.GeneratedProtocolMessageType('ListPairsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPAIRSRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListPairsResponse)
  ))
_sym_db.RegisterMessage(ListPairsResponse)

ListPeersRequest = _reflection.GeneratedProtocolMessageType('ListPeersRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPEERSREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListPeersRequest)
  ))
_sym_db.RegisterMessage(ListPeersRequest)

ListPeersResponse = _reflection.GeneratedProtocolMessageType('ListPeersResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPEERSRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ListPeersResponse)
  ))
_sym_db.RegisterMessage(ListPeersResponse)

LndChannels = _reflection.GeneratedProtocolMessageType('LndChannels', (_message.Message,), dict(
  DESCRIPTOR = _LNDCHANNELS,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.LndChannels)
  ))
_sym_db.RegisterMessage(LndChannels)

LndInfo = _reflection.GeneratedProtocolMessageType('LndInfo', (_message.Message,), dict(
  DESCRIPTOR = _LNDINFO,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.LndInfo)
  ))
_sym_db.RegisterMessage(LndInfo)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), dict(
  DESCRIPTOR = _ORDER,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.Order)
  ))
_sym_db.RegisterMessage(Order)

OrderRemoval = _reflection.GeneratedProtocolMessageType('OrderRemoval', (_message.Message,), dict(
  DESCRIPTOR = _ORDERREMOVAL,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.OrderRemoval)
  ))
_sym_db.RegisterMessage(OrderRemoval)

Orders = _reflection.GeneratedProtocolMessageType('Orders', (_message.Message,), dict(
  DESCRIPTOR = _ORDERS,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.Orders)
  ))
_sym_db.RegisterMessage(Orders)

OrdersCount = _reflection.GeneratedProtocolMessageType('OrdersCount', (_message.Message,), dict(
  DESCRIPTOR = _ORDERSCOUNT,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.OrdersCount)
  ))
_sym_db.RegisterMessage(OrdersCount)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), dict(

  LndPubKeysEntry = _reflection.GeneratedProtocolMessageType('LndPubKeysEntry', (_message.Message,), dict(
    DESCRIPTOR = _PEER_LNDPUBKEYSENTRY,
    __module__ = 'xurpc_pb2'
    # @@protoc_insertion_point(class_scope:xudrpc.Peer.LndPubKeysEntry)
    ))
  ,
  DESCRIPTOR = _PEER,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.Peer)
  ))
_sym_db.RegisterMessage(Peer)
_sym_db.RegisterMessage(Peer.LndPubKeysEntry)

PlaceOrderRequest = _reflection.GeneratedProtocolMessageType('PlaceOrderRequest', (_message.Message,), dict(
  DESCRIPTOR = _PLACEORDERREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.PlaceOrderRequest)
  ))
_sym_db.RegisterMessage(PlaceOrderRequest)

PlaceOrderResponse = _reflection.GeneratedProtocolMessageType('PlaceOrderResponse', (_message.Message,), dict(
  DESCRIPTOR = _PLACEORDERRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.PlaceOrderResponse)
  ))
_sym_db.RegisterMessage(PlaceOrderResponse)

PlaceOrderEvent = _reflection.GeneratedProtocolMessageType('PlaceOrderEvent', (_message.Message,), dict(
  DESCRIPTOR = _PLACEORDEREVENT,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.PlaceOrderEvent)
  ))
_sym_db.RegisterMessage(PlaceOrderEvent)

RaidenInfo = _reflection.GeneratedProtocolMessageType('RaidenInfo', (_message.Message,), dict(
  DESCRIPTOR = _RAIDENINFO,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RaidenInfo)
  ))
_sym_db.RegisterMessage(RaidenInfo)

RemoveCurrencyRequest = _reflection.GeneratedProtocolMessageType('RemoveCurrencyRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVECURRENCYREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RemoveCurrencyRequest)
  ))
_sym_db.RegisterMessage(RemoveCurrencyRequest)

RemoveCurrencyResponse = _reflection.GeneratedProtocolMessageType('RemoveCurrencyResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOVECURRENCYRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RemoveCurrencyResponse)
  ))
_sym_db.RegisterMessage(RemoveCurrencyResponse)

RemoveOrderRequest = _reflection.GeneratedProtocolMessageType('RemoveOrderRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEORDERREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RemoveOrderRequest)
  ))
_sym_db.RegisterMessage(RemoveOrderRequest)

RemoveOrderResponse = _reflection.GeneratedProtocolMessageType('RemoveOrderResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEORDERRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RemoveOrderResponse)
  ))
_sym_db.RegisterMessage(RemoveOrderResponse)

RemovePairRequest = _reflection.GeneratedProtocolMessageType('RemovePairRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEPAIRREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RemovePairRequest)
  ))
_sym_db.RegisterMessage(RemovePairRequest)

RemovePairResponse = _reflection.GeneratedProtocolMessageType('RemovePairResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEPAIRRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.RemovePairResponse)
  ))
_sym_db.RegisterMessage(RemovePairResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ShutdownRequest)
  ))
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.ShutdownResponse)
  ))
_sym_db.RegisterMessage(ShutdownResponse)

SubscribeAddedOrdersRequest = _reflection.GeneratedProtocolMessageType('SubscribeAddedOrdersRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEADDEDORDERSREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.SubscribeAddedOrdersRequest)
  ))
_sym_db.RegisterMessage(SubscribeAddedOrdersRequest)

SubscribeRemovedOrdersRequest = _reflection.GeneratedProtocolMessageType('SubscribeRemovedOrdersRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREMOVEDORDERSREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.SubscribeRemovedOrdersRequest)
  ))
_sym_db.RegisterMessage(SubscribeRemovedOrdersRequest)

SubscribeSwapsRequest = _reflection.GeneratedProtocolMessageType('SubscribeSwapsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBESWAPSREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.SubscribeSwapsRequest)
  ))
_sym_db.RegisterMessage(SubscribeSwapsRequest)

SwapSuccess = _reflection.GeneratedProtocolMessageType('SwapSuccess', (_message.Message,), dict(
  DESCRIPTOR = _SWAPSUCCESS,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.SwapSuccess)
  ))
_sym_db.RegisterMessage(SwapSuccess)

UnbanRequest = _reflection.GeneratedProtocolMessageType('UnbanRequest', (_message.Message,), dict(
  DESCRIPTOR = _UNBANREQUEST,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.UnbanRequest)
  ))
_sym_db.RegisterMessage(UnbanRequest)

UnbanResponse = _reflection.GeneratedProtocolMessageType('UnbanResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNBANRESPONSE,
  __module__ = 'xurpc_pb2'
  # @@protoc_insertion_point(class_scope:xudrpc.UnbanResponse)
  ))
_sym_db.RegisterMessage(UnbanResponse)


_CHANNELBALANCERESPONSE_BALANCESENTRY._options = None
_GETINFORESPONSE_LNDENTRY._options = None
_LISTORDERSRESPONSE_ORDERSENTRY._options = None
_PEER_LNDPUBKEYSENTRY._options = None

_XUD = _descriptor.ServiceDescriptor(
  name='Xud',
  full_name='xudrpc.Xud',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5424,
  serialized_end=7624,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddCurrency',
    full_name='xudrpc.Xud.AddCurrency',
    index=0,
    containing_service=None,
    input_type=_ADDCURRENCYREQUEST,
    output_type=_ADDCURRENCYRESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/addcurrency:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='AddPair',
    full_name='xudrpc.Xud.AddPair',
    index=1,
    containing_service=None,
    input_type=_ADDPAIRREQUEST,
    output_type=_ADDPAIRRESPONSE,
    serialized_options=_b('\202\323\344\223\002\020\"\013/v1/addpair:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOrder',
    full_name='xudrpc.Xud.RemoveOrder',
    index=2,
    containing_service=None,
    input_type=_REMOVEORDERREQUEST,
    output_type=_REMOVEORDERRESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/removeorder:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ChannelBalance',
    full_name='xudrpc.Xud.ChannelBalance',
    index=3,
    containing_service=None,
    input_type=_CHANNELBALANCEREQUEST,
    output_type=_CHANNELBALANCERESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\022\022/v1/channelbalance'),
  ),
  _descriptor.MethodDescriptor(
    name='Connect',
    full_name='xudrpc.Xud.Connect',
    index=4,
    containing_service=None,
    input_type=_CONNECTREQUEST,
    output_type=_CONNECTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\020\"\013/v1/connect:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Ban',
    full_name='xudrpc.Xud.Ban',
    index=5,
    containing_service=None,
    input_type=_BANREQUEST,
    output_type=_BANRESPONSE,
    serialized_options=_b('\202\323\344\223\002\014\"\007/v1/ban:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Unban',
    full_name='xudrpc.Xud.Unban',
    index=6,
    containing_service=None,
    input_type=_UNBANREQUEST,
    output_type=_UNBANRESPONSE,
    serialized_options=_b('\202\323\344\223\002\016\"\t/v1/unban:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetInfo',
    full_name='xudrpc.Xud.GetInfo',
    index=7,
    containing_service=None,
    input_type=_GETINFOREQUEST,
    output_type=_GETINFORESPONSE,
    serialized_options=_b('\202\323\344\223\002\n\022\010/v1/info'),
  ),
  _descriptor.MethodDescriptor(
    name='GetNodeInfo',
    full_name='xudrpc.Xud.GetNodeInfo',
    index=8,
    containing_service=None,
    input_type=_GETNODEINFOREQUEST,
    output_type=_GETNODEINFORESPONSE,
    serialized_options=_b('\202\323\344\223\002\016\022\014/v1/nodeinfo'),
  ),
  _descriptor.MethodDescriptor(
    name='ListOrders',
    full_name='xudrpc.Xud.ListOrders',
    index=9,
    containing_service=None,
    input_type=_LISTORDERSREQUEST,
    output_type=_LISTORDERSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\014\022\n/v1/orders'),
  ),
  _descriptor.MethodDescriptor(
    name='ListCurrencies',
    full_name='xudrpc.Xud.ListCurrencies',
    index=10,
    containing_service=None,
    input_type=_LISTCURRENCIESREQUEST,
    output_type=_LISTCURRENCIESRESPONSE,
    serialized_options=_b('\202\323\344\223\002\020\022\016/v1/currencies'),
  ),
  _descriptor.MethodDescriptor(
    name='ListPairs',
    full_name='xudrpc.Xud.ListPairs',
    index=11,
    containing_service=None,
    input_type=_LISTPAIRSREQUEST,
    output_type=_LISTPAIRSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\013\022\t/v1/pairs'),
  ),
  _descriptor.MethodDescriptor(
    name='ListPeers',
    full_name='xudrpc.Xud.ListPeers',
    index=12,
    containing_service=None,
    input_type=_LISTPEERSREQUEST,
    output_type=_LISTPEERSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\013\022\t/v1/peers'),
  ),
  _descriptor.MethodDescriptor(
    name='PlaceOrder',
    full_name='xudrpc.Xud.PlaceOrder',
    index=13,
    containing_service=None,
    input_type=_PLACEORDERREQUEST,
    output_type=_PLACEORDEREVENT,
    serialized_options=_b('\202\323\344\223\002\023\"\016/v1/placeorder:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PlaceOrderSync',
    full_name='xudrpc.Xud.PlaceOrderSync',
    index=14,
    containing_service=None,
    input_type=_PLACEORDERREQUEST,
    output_type=_PLACEORDERRESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/placeordersync:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteSwap',
    full_name='xudrpc.Xud.ExecuteSwap',
    index=15,
    containing_service=None,
    input_type=_EXECUTESWAPREQUEST,
    output_type=_SWAPSUCCESS,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/executeswap:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveCurrency',
    full_name='xudrpc.Xud.RemoveCurrency',
    index=16,
    containing_service=None,
    input_type=_REMOVECURRENCYREQUEST,
    output_type=_REMOVECURRENCYRESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/removecurrency:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemovePair',
    full_name='xudrpc.Xud.RemovePair',
    index=17,
    containing_service=None,
    input_type=_REMOVEPAIRREQUEST,
    output_type=_REMOVEPAIRRESPONSE,
    serialized_options=_b('\202\323\344\223\002\023\"\016/v1/removepair:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Shutdown',
    full_name='xudrpc.Xud.Shutdown',
    index=18,
    containing_service=None,
    input_type=_SHUTDOWNREQUEST,
    output_type=_SHUTDOWNRESPONSE,
    serialized_options=_b('\202\323\344\223\002\021\"\014/v1/shutdown:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeAddedOrders',
    full_name='xudrpc.Xud.SubscribeAddedOrders',
    index=19,
    containing_service=None,
    input_type=_SUBSCRIBEADDEDORDERSREQUEST,
    output_type=_ORDER,
    serialized_options=_b('\202\323\344\223\002\032\022\030/v1/subscribeaddedorders'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeRemovedOrders',
    full_name='xudrpc.Xud.SubscribeRemovedOrders',
    index=20,
    containing_service=None,
    input_type=_SUBSCRIBEREMOVEDORDERSREQUEST,
    output_type=_ORDERREMOVAL,
    serialized_options=_b('\202\323\344\223\002\034\022\032/v1/subscriberemovedorders'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeSwaps',
    full_name='xudrpc.Xud.SubscribeSwaps',
    index=21,
    containing_service=None,
    input_type=_SUBSCRIBESWAPSREQUEST,
    output_type=_SWAPSUCCESS,
    serialized_options=_b('\202\323\344\223\002\024\022\022/v1/subscribeswaps'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeSwapFailures',
    full_name='xudrpc.Xud.SubscribeSwapFailures',
    index=22,
    containing_service=None,
    input_type=_SUBSCRIBESWAPSREQUEST,
    output_type=_SWAPFAILURE,
    serialized_options=_b('\202\323\344\223\002\033\022\031/v1/subscribeswapfailures'),
  ),
])
_sym_db.RegisterServiceDescriptor(_XUD)

DESCRIPTOR.services_by_name['Xud'] = _XUD

# @@protoc_insertion_point(module_scope)
